package com.dsic.gj_erp.wsclient;

import com.alibaba.fastjson.JSONObject;
import com.dsic.gj_erp.wsclient.handler.ZxHandler;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.web.socket.TextMessage;
import org.springframework.web.socket.WebSocketSession;
import org.springframework.web.socket.client.WebSocketClient;
import org.springframework.web.socket.client.WebSocketConnectionManager;
import org.springframework.web.socket.handler.TextWebSocketHandler;

@Slf4j
@Service
@RequiredArgsConstructor
public class WebSocketService extends TextWebSocketHandler {

    private WebSocketSession session;

    private final WebSocketClient client;

    private final ZxHandler zxHandler;


    public void connect(String uri) {
        WebSocketConnectionManager manager = new WebSocketConnectionManager(client, this, uri);
        manager.start();
    }

    public void disconnect() throws Exception {
        if (session != null && session.isOpen()) {
            session.close();
        }
    }

    public void sendMessage(String message) throws Exception {
        if (session != null && session.isOpen()) {
            session.sendMessage(new TextMessage(message));
        } else {
            throw new IllegalStateException("WebSocket is not connected.");
        }
    }

    @Override
    public void afterConnectionEstablished(WebSocketSession session) throws Exception {
        this.session = session; // 处理连接后保存session
    }

    @Override
    protected void handleTextMessage(WebSocketSession session, TextMessage message) throws Exception {
        log.info("语音上报:{}",message.getPayload());
        Message msg= JSONObject.parseObject(message.getPayload(),Message.class);
        switch (msg.getCodeEx()){
            case REG:
                log.info("设备{},连接成功",msg.getMsg().getDeviceId());
                break;
            case ZX:
                zxHandler.execute(msg);
                break;
        }
    }

    public WebSocketSession getSession(){
        return this.session;
    }

}
